# baggo

There was a farmer who had a dog and baggo was his name-o. Except the farmer was a programmer, and the dog was a roguelike library.

## Features

1. A terminal like display and renderer for [code page 437](https://en.wikipedia.org/wiki/Code_page_437) fonts.
2. Input Handling.

![A minimal roguelike screen from running sandbox.py](sandbox.png)

## Installation

```shell
pip install baggo
```

## Development

First make sure to [install uv](https://docs.astral.sh/uv/getting-started/installation/)

Assuming you have uv installed, run:

```shell
uv sync
```

You can now the basic sandbox example with:

```shell
uv run sandbox.py
```
